@@ -28,6 +28,7 @@ from sqlalchemy.sql import operators, extract
 from sqlalchemy.ext.declarative import declarative_base, DeclarativeMeta
 from sqlalchemy.util import to_list
 from .signals import Namespace
+from .util import set_default_option
 
 import tornado.web
 from tornado.options import options
@@ -508,3 +509,8 @@ db = SQLAlchemy.create_instance(
     #: {'pool_recycle': 3600}
     options.sqlalchemy_kwargs,
 )
+
+#: sqlalchemy default configuration
+set_default_option('sqlalchemy_engine', type=str, help='databse engine')
+set_default_option('sqlalchemy_kwargs', default={},
+                   type=dict, help='sqlalchemy extra params')
